# This allows to use "from utils import conversion" in __main__.py
# import os, sys

__version__ = '0.2.1'
__description__ = 'A TOOL for Ping of Hosts'
__author__ = 'Chaoqun Chen'
__author_email__ = 'chen.chaoqun.ext@99cloud.net'
__url__ = 'https://github.com/tsunchen/script'
